Module julia::api
[−]
[src]
Main entry point to the Julia api.
Reexports
pub use self::value::Value; |
pub use self::value::JlValue; |
pub use self::array::Array; |
pub use self::array::Svec; |
pub use self::function::Function; |
pub use self::sym::Symbol; |
pub use self::sym::IntoSymbol; |
pub use self::module::Module; |
pub use self::datatype::Datatype; |
pub use self::task::Task; |
pub use self::exception::Exception; |
pub use self::primitive::*; |
Modules
| array |
Module providing wrappers for iteratable sequences. |
| datatype |
Module providing wrappers for the native Julia type-types. |
| exception |
Module providing wrappers for the native Julia exceptions. |
| function |
Module providing a wrapper for the native Julia function object. |
| module |
Module providing a wrapper for the native Julia module object. |
| primitive |
Module providing Rusty versions of the native Julia primitive types and abstract types describing them. |
| sym |
Module providing a wrapper for the native Julia symbol. |
| task |
Module providing a wrapper for the native Julia task object. |
| value |
Module containing traits, types and macros for interfacing with Julia values. |
Structs
| Gc |
Blank struct for controlling the Julia garbage collector. |
| Julia |
Struct for controlling the Julia runtime. |